Nameko
######

.. image:: https://secure.travis-ci.org/onefinestay/nameko.png?branch=master
   :target: http://travis-ci.org/onefinestay/nameko

**Nameko** ``[nah-meh-koh]`` (noun)

#. amber-brown mushroom with a slightly gelatinous coating that is used as an ingredient in miso soup and nabemono.
#. python services framework on top of AMQP


License
-------

Apache 2.0. See LICENSE for details.
